# -*- coding: utf-8 -*-

"""
a couple of variable to use throughout the app
"""

default_app_config = "discordpingformatter.apps.AaDiscordPingFormatterConfig"

__version__ = "2.0.0a4"
__title__ = "Fleet Ping Formatter"
