# Generated by Django 2.2.15 on 2020-09-12 15:06

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ("discordpingformatter", "0002_initialize_db"),
    ]

    operations = [
        migrations.AlterField(
            model_name="discordpingtargets",
            name="discord_id",
            field=models.CharField(
                blank=True,
                help_text="ID of the Discord role to ping",
                max_length=255,
                unique=True,
            ),
        ),
        migrations.AlterField(
            model_name="discordpingtargets",
            name="name",
            field=models.OneToOneField(
                help_text="Name of the Discord role to ping",
                on_delete=django.db.models.deletion.CASCADE,
                to="auth.Group",
            ),
        ),
        migrations.AlterField(
            model_name="discordpingtargets",
            name="restricted_to_group",
            field=models.ManyToManyField(
                help_text="Restrict Discord group to the following group(s) ...",
                related_name="discord_role_require_groups",
                to="auth.Group",
            ),
        ),
        migrations.AlterField(
            model_name="webhook",
            name="restricted_to_group",
            field=models.ManyToManyField(
                help_text="Restrict this webhook to the following group(s) ...",
                related_name="webhook_require_groups",
                to="auth.Group",
            ),
        ),
        migrations.AlterField(
            model_name="webhook",
            name="url",
            field=models.CharField(
                help_text="URL of this webhook, e.g. https://discordapp.com/api/webhooks/123456/abcdef or https://hooks.slack.com/services/xxxx/xxxx",
                max_length=255,
                unique=True,
            ),
        ),
    ]
